@@ -28,33 +28,42 @@ class API(object):
         self.scheduler_client = scheduler_client.SchedulerClient()
         super(API, self).__init__()
 
-    def container_create(self, context, new_container):
+    def container_create(self, context, new_container, extra_spec,
+                         requested_networks):
+        host_state = None
         try:
-            self._schedule_container(context, new_container)
+            host_state = self._schedule_container(context, new_container,
+                                                  extra_spec)
         except Exception as exc:
             new_container.status = consts.ERROR
             new_container.status_reason = str(exc)
             new_container.save(context)
             return
 
-        self.rpcapi.container_create(context, new_container)
+        self.rpcapi.container_create(context, host_state['host'],
+                                     new_container, host_state['limits'],
+                                     requested_networks)
 
-    def container_run(self, context, new_container):
+    def container_run(self, context, new_container, extra_spec,
+                      requested_networks):
+        host_state = None
         try:
-            self._schedule_container(context, new_container)
+            host_state = self._schedule_container(context, new_container,
+                                                  extra_spec)
         except Exception as exc:
             new_container.status = consts.ERROR
             new_container.status_reason = str(exc)
             new_container.save(context)
             return
 
-        self.rpcapi.container_run(context, new_container)
+        self.rpcapi.container_run(context, host_state['host'], new_container,
+                                  host_state['limits'], requested_networks)
 
-    def _schedule_container(self, context, new_container):
+    def _schedule_container(self, context, new_container, extra_spec):
         dests = self.scheduler_client.select_destinations(context,
-                                                          [new_container])
-        new_container.host = dests[0]['host']
-        new_container.save(context)
+                                                          [new_container],
+                                                          extra_spec)
+        return dests[0]
 
     def container_delete(self, context, container, *args):
         return self.rpcapi.container_delete(context, container, *args)
@@ -68,14 +77,14 @@ class API(object):
     def container_stop(self, context, container, *args):
         return self.rpcapi.container_stop(context, container, *args)
 
-    def container_start(self, context, container, *args):
-        return self.rpcapi.container_start(context, container, *args)
+    def container_start(self, context, container):
+        return self.rpcapi.container_start(context, container)
 
-    def container_pause(self, context, container, *args):
-        return self.rpcapi.container_pause(context, container, *args)
+    def container_pause(self, context, container):
+        return self.rpcapi.container_pause(context, container)
 
-    def container_unpause(self, context, container, *args):
-        return self.rpcapi.container_unpause(context, container, *args)
+    def container_unpause(self, context, container):
+        return self.rpcapi.container_unpause(context, container)
 
     def container_logs(self, context, container, stdout, stderr,
                        timestamps, tail, since):
@@ -106,11 +115,34 @@ class API(object):
     def container_get_archive(self, context, container, *args):
         return self.rpcapi.container_get_archive(context, container, *args)
 
+    def add_security_group(self, context, container, *args):
+        return self.rpcapi.add_security_group(context, container, *args)
+
     def container_put_archive(self, context, container, *args):
         return self.rpcapi.container_put_archive(context, container, *args)
 
-    def image_pull(self, context, image, *args):
-        return self.rpcapi.image_pull(context, image, *args)
+    def container_stats(self, context, container):
+        return self.rpcapi.container_stats(context, container)
+
+    def container_commit(self, context, container, *args):
+        return self.rpcapi.container_commit(context, container, *args)
+
+    def image_pull(self, context, image):
+        return self.rpcapi.image_pull(context, image)
 
     def image_search(self, context, image, image_driver, *args):
         return self.rpcapi.image_search(context, image, image_driver, *args)
+
+    def capsule_create(self, context, new_capsule,
+                       requested_networks=None, extra_spec=None):
+        host_state = None
+        try:
+            host_state = self._schedule_container(context, new_capsule,
+                                                  extra_spec)
+        except Exception as exc:
+            new_capsule.status = consts.ERROR
+            new_capsule.status_reason = str(exc)
+            new_capsule.save(context)
+            return
+        self.rpcapi.capsule_create(context, host_state['host'], new_capsule,
+                                   requested_networks, host_state['limits'])
