@@ -73,16 +73,6 @@ class MyObj(base.ZunPersistentObject, base.ZunObject):
         self.foo = 42
 
 
-class MyObj2(object):
-    @classmethod
-    def obj_name(cls):
-        return 'MyObj'
-
-    @base.remotable_classmethod
-    def get(cls, *args, **kwargs):
-        pass
-
-
 @base.ZunObjectRegistry.register_if(False)
 class TestSubclassedObject(MyObj):
     fields = {'new_field': fields.StringField()}
@@ -352,17 +342,18 @@ class TestObject(test_base.TestCase, _TestObject):
 # object (fields and remotable methods). If either the version or hash
 # change, the static tree needs to be updated.
 # For more information on object version testing, read
-# http://docs.openstack.org/developer/zun/objects.html
+# https://docs.openstack.org/zun/latest/
 object_data = {
-    'Container': '1.15-b2f1403b9bfcd97b52f46d2c53f003a5',
+    'Container': '1.18-e611f6b0fbc9f5f5c1164545b1630268',
     'Image': '1.0-0b976be24f4f6ee0d526e5c981ce0633',
     'MyObj': '1.0-34c4b1aadefd177b13f9a2f894cc23cd',
     'NUMANode': '1.0-cba878b70b2f8b52f1e031b41ac13b4e',
     'NUMATopology': '1.0-b54086eda7e4b2e6145ecb6ee2c925ab',
     'ResourceClass': '1.1-d661c7675b3cd5b8c3618b68ba64324e',
     'ResourceProvider': '1.0-92b427359d5a4cf9ec6c72cbe630ee24',
-    'ZunService': '1.0-2a19ab9987a746621b2ada02d8aadf22',
-    'ComputeNode': '1.4-d73867b95a525c60cbbb5e98c0dc0dd6',
+    'ZunService': '1.1-b1549134bfd5271daec417ca8cabc77e',
+    'ComputeNode': '1.6-33a173b969781644a95ea2925eb5cca2',
+    'Capsule': '1.0-0dce1bd569773c35193d75c285226e75',
 }
 
 
@@ -380,8 +371,8 @@ class TestObjectVersions(test_base.TestCase):
                          "changed. Make sure the versions of the objects has "
                          "been bumped, and update the hashes in the static "
                          "fingerprints tree (object_data). For more "
-                         "information, read http://docs.openstack.org/"
-                         "developer/zun/objects.html.")
+                         "information, read https://docs.openstack.org/"
+                         "zun/latest/contributor/objects.html.")
 
 
 class TestObjectSerializer(test_base.TestCase):
